@@ -16,9 +16,3 @@ then
     /usr/bin/cp /etc/defaults/etc/profile.d/bindkey.tcsh /etc/profile.d/bindkey.tcsh
 fi
 
-if [ ! -f /etc/profile.d/complete.tcsh ]
-then
-    /usr/bin/mkdir -p /etc/profile.d
-    /usr/bin/cp /etc/defaults/etc/profile.d/complete.tcsh /etc/profile.d/complete.tcsh
-fi
-
